<?php

/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package saasland
 */

// Theme settings options
$opt = get_option( 'saasland_opt' );

/**
* Header Nav-bar Layout
 */
$page_header_layout = function_exists( 'get_field' ) ? get_field( 'header_layout' ) : '';

if( !empty($page_header_layout) && $page_header_layout != 'default' ) {
    $nav_layout = $page_header_layout;
} elseif ( !empty($_GET['menu']) ) {
    $nav_layout = $_GET['menu'];
} else {
    $nav_layout = !empty($opt['nav_layout']) ? $opt['nav_layout'] : '';
}

$nav_layout_header = '';
$nav_layout_start = '<div class="container">';
$nav_layout_end = '</div>';

switch ( $nav_layout ) {
    case 'boxed':
        $nav_layout_start = '<div class="container">';
        $nav_layout_end = '</div>';
        $nav_layout_header = '';
        break;
    case 'wide':
        $nav_layout_start = '<div class="container custom_container">';
        $nav_layout_end = '</div>';
        $nav_layout_header = '';
        break;
    case 'full_width':
        $nav_layout_start = '';
        $nav_layout_header = 'header_area_three header_area_five nav_full_width';
        $nav_layout_end = '';
        break;
}

/**
* Menu Alignment
 */
$menu_alignment = !empty($opt['menu_alignment']) ? $opt['menu_alignment'] : 'menu_right';
if ( !empty($_GET['menu_align']) ) {
    $menu_alignment = $_GET['menu_align'];
}
switch ( $menu_alignment ) {
    case 'menu_right':
        $nav_alignment = 'navbar navbar-expand-lg menu_one menu_right';
        $ul_class = ' ml-auto';
        $menu_container = '';
        break;
    case 'menu_left':
        $nav_alignment = 'navbar navbar-expand-lg menu_one menu_four menu_left';
        $ul_class = ' pl_120';
        $menu_container = '';
        break;
    case 'menu_center':
        $nav_alignment = 'navbar navbar-expand-lg menu_center';
        $menu_container = 'justify-content-center';
        $ul_class = ' ml-auto mr-auto';
        break;
}

// Is Banner
$is_banner = '1';
if ( is_home() ) {
    $is_banner = '1';
} elseif ( is_page() || is_singular('post') || is_singular( 'job' ) || is_singular('product') ) {
    $is_banner = function_exists( 'get_field' ) ? get_field( 'is_banner' ) : '1';
    $is_banner = isset($is_banner) ? $is_banner : '1';
}
if ( is_404() || is_page_template('elementor_canvas') ) {
    $is_banner = '';
}
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
    <head>
        <meta charset="<?php bloginfo( 'charset' ); ?>">
        <!-- For IE -->
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <!-- For Resposive Device -->
        <meta name="viewport" content="width=device-width, initial-scale=1.0">

        <?php wp_head(); ?>
    </head>

    <body <?php body_class(); ?> data-spy="scroll" data-target=".navbar" data-offset="70">
    <?php
    if ( function_exists('wp_body_open') ) {
        wp_body_open();
    }
    ?>

    <?php get_template_part('template-parts/header_elements/preloader'); ?>

    <div class="body_wrapper">
        <?php
        $header_style = '';
        if( !empty($opt['header_style']) && ($opt['header_style'] != 'default' ) ) {
            $header_style = new WP_Query(array(
                'post_type' => 'header',
                'posts_per_page' => -1,
                'p' => $opt['header_style'],
            ));
        }

        if( $header_style != '' ) {
            if ( $header_style->have_posts() ) {
                while ($header_style->have_posts() ) : $header_style->the_post();
                    the_content();
                endwhile;
                wp_reset_postdata();
            }
        } else {

            if ( isset($opt['is_header_sticky']) ) {
                $is_header_sticky = $opt['is_header_sticky'] == '1' ? ' header_stick' : '';
            }
            else {
                $is_header_sticky = ' header_stick';
            }

            if ( is_page_template( 'page-agency-colorful.php' ) ) {
                $is_header_sticky = '';
            }
            ?>

            <header class="header_area <?php echo esc_attr($nav_layout_header.$is_header_sticky); ?>">
                <?php
                $is_header_top = !empty($opt['is_header_top']) ? $opt['is_header_top'] : '';
                if ( $is_header_top == '1' ) :
                    get_template_part('template-parts/header_elements/header-top');
                endif;
                ?>
                <nav class="<?php echo esc_attr($nav_alignment) ?>">
                    <?php echo wp_kses_post($nav_layout_start); ?>

                    <?php get_template_part('template-parts/header_elements/logo'); ?>

                    <?php
                    $is_menu_btn = !empty($opt['is_menu_btn']) ? $opt['is_menu_btn'] : '';
                    if (!empty($menu_btn_title) & $is_menu_btn == '1' ) : ?>
                        <a class="btn_get btn_hover mobile_btn ml-auto" href="<?php echo esc_url($menu_btn_url); ?>">
                            <?php echo esc_html($menu_btn_title); ?>
                        </a>
                    <?php endif; ?>

                    <?php get_template_part('template-parts/header_elements/navbar'); ?>

                    <?php
                    get_template_part( 'template-parts/header_elements/mini-cart' );
                    echo wp_kses_post($nav_layout_end);
                    ?>
                </nav>
            </header>
            <?php
        }

        if ( is_home() ) {
            $banner_style = !empty($opt['blog_banner_style']) ? $opt['blog_banner_style'] : '2';
        } else {
            $banner_style = !empty($opt['banner_style']) ? $opt['banner_style'] : '1';
        }

        if ( !isset($_GET['elementor_library']) ) {
            if ( $is_banner == '1' ) {
                if (!is_singular( 'post')) {
                    if ($banner_style == '1' ) {
                        get_template_part( 'template-parts/header_elements/banner' );
                    } elseif ($banner_style == '2' ) {
                        get_template_part( 'template-parts/header_elements/banner2' );
                    }
                } elseif ( is_singular('post') ) {
                    get_template_part( 'template-parts/header_elements/banner-post' );
                }
            }
        }